# jsondler

JSON handler for Python

## Installation

To install the package from PyPI type:

```
pip install jsondler
```

Or from the repo:

```
pip install git+https://github.com/loven-doo/jsondler.git
```

For 'dev' branch version:

```
pip install git+https://github.com/loven-doo/jsondler.git@dev
```

## Package reference

### DictsList

### json_tools

